@@ -17,7 +17,7 @@ from ..elastic import (
 )
 
 
-def elastic():
+def elastic(environment: str = None) -> ElasticDataSource:
     rc_run_data = RelationshipConfig()
     rc_run_data.to_one = {'benchling_extraction': 'extraction',
                           'benchling_sample': 'sample',
@@ -305,7 +305,7 @@ def elastic():
                     """
                 }
             },
-            'calc_specimen_needed_psyche': {
+            'calc_specimen_needed_at_sanger_psyche': {
                 'type': 'boolean',
                 'script': {
                     'source': """
@@ -334,46 +334,107 @@ def elastic():
                             doc['tolid_tolid_count'].size() > 0
                         );
 
-                        boolean isSampleCollected = (
-                            doc.containsKey('goat_sample_collected.keyword') &&
-                            doc['goat_sample_collected.keyword'].size() > 0 &&
-                            ['AG100PEST', 'i5K', 'CNGB', 'CANBP', 'CBP',
-                            'ERGA-PIL', 'ERGA-BGE', 'ERGA-CH','ENDEMIXIT'].contains(
-                            doc['goat_sample_collected.keyword'].value)
+                        emit(
+                            isRecollectionRequired || (!isIncludedProject
+                            && !isChromosome && !isSpecimensAtSanger)
                         );
+                    """
+                }
+            },
+            'calc_specimen_collection_needed_psyche': {
+                'type': 'boolean',
+                'script': {
+                    'source': """
+                        boolean isRecollectionRequired = (
+                            doc.containsKey('sts_sequencing_material_status.keyword') &&
+                            doc['sts_sequencing_material_status.keyword'].size() > 0 &&
+                            doc['sts_sequencing_material_status.keyword'].value
+                            == 'RECOLLECTION_REQUIRED'
+                        );
+
+                        boolean isIncludedProject = (
+                            doc.containsKey('goat_long_list.keyword') &&
+                            doc['goat_long_list.keyword'].size() > 0 &&
+                            ['AG100PEST', 'i5K', 'CBP', 'ERGA-PIL', 'ERGA-BGE', 'ERGA-CH',
+                            'ENDEMIXIT'].contains(doc['goat_long_list.keyword'].value)
+                        );
+
+                        boolean isChromosome = (
+                            doc.containsKey('goat_assembly_level.keyword') &&
+                            doc['goat_assembly_level.keyword'].size() > 0 &&
+                            doc['goat_assembly_level.keyword'].value == 'Chromosome'
+                        );
+
+                        boolean isSpecimensAtSanger = (
+                            doc.containsKey('tolid_tolid_count') &&
+                            doc['tolid_tolid_count'].size() > 0
+                        );
+
+                        boolean isSampleCollectedForPsyche = false;
+                        if (doc.containsKey('goat_sample_collected.keyword') &&
+                            doc['goat_sample_collected.keyword'].size() > 0) {
+                            for (String value : doc['goat_sample_collected.keyword']) {
+                                if (value != null && value.contains('PSYCHE')) {
+                                    isSampleCollectedForPsyche = true;
+                                    break;
+                                }
+                            }
+                        }
 
                         emit(
                             isRecollectionRequired || (!isIncludedProject
-                            && !isChromosome && !isSpecimensAtSanger && !isSampleCollected)
+                            && !isChromosome && !isSpecimensAtSanger
+                            && !isSampleCollectedForPsyche)
                         );
                     """
                 }
             },
+            'calc_species_epithet': {
+                'type': 'keyword',
+                'script': {
+                    'source': """
+                        String result = "";
+                        if (doc.containsKey('goat_species_name.keyword')) {
+                            def values = doc['goat_species_name.keyword'];
+                            if (values.size() > 0) {
+                                String fullName = values.value;
+                                int firstSpace = fullName.indexOf(' ');
+                                if (firstSpace > 0 && firstSpace < fullName.length() - 1) {
+                                    int secondSpace = fullName.indexOf(' ', firstSpace + 1);
+                                    if (secondSpace > 0) {
+                                        result = fullName.substring(firstSpace + 1, secondSpace);
+                                    } else {
+                                        result = fullName.substring(firstSpace + 1);
+                                    }
+                                }
+                            }
+                        }
+                        emit(result);
+                    """
+                }
+            },
             'calc_recollection_needed': {
                 'type': 'boolean',
                 'script': {
                     'source': """
                         boolean isTopUpCountZero = (
-                            doc.containsKey
-                            ('calc_topup_required_tolid_calc_topup_required_value_count')
-                            && doc
-                            ['calc_topup_required_tolid_calc_topup_required_value_count']
-                            .size() > 0 && doc
-                            ['calc_topup_required_tolid_calc_topup_required_value_count']
-                            .value == 0
+                            (!doc.containsKey('calc_topup_required_tolid_count') ||
+                            doc['calc_topup_required_tolid_count'].size() == 0) ||
+                            (doc.containsKey('calc_topup_required_tolid_count') &&
+                            doc['calc_topup_required_tolid_count'].size() > 0 &&
+                            doc['calc_topup_required_tolid_count'].value == 0)
                         );
 
                         boolean isIndividualExhaustedCountZero = (
-                            doc.containsKey
-                            ('calc_individual_exhausted_tolid_calc_individual_exhausted_value_count')
-                            && doc
-                            ['calc_individual_exhausted_tolid_calc_individual_exhausted_value_count']
-                            .size() > 0 && doc
-                            ['calc_individual_exhausted_tolid_calc_individual_exhausted_value_count']
-                            .value == 0
+                            (!doc.containsKey('calc_individual_exhausted_tolid_count') ||
+                            doc['calc_individual_exhausted_tolid_count'].size() == 0) ||
+                            (doc.containsKey('calc_individual_exhausted_tolid_count') &&
+                            doc['calc_individual_exhausted_tolid_count'].size() > 0 &&
+                            doc['calc_individual_exhausted_tolid_count'].value == 0)
                         );
 
-                        boolean isIndividualNovel = (
+                        boolean isIndividualNovel =
+                        (
                             isTopUpCountZero && isIndividualExhaustedCountZero
                         );
 
@@ -390,13 +451,16 @@ def elastic():
                         );
 
                         boolean isRecollectionNeeded = (
-                            doc.containsKey
-                            ('calc_individual_exhausted_tolid_calc_individual_exhausted_value_count')
-                            && doc.containsKey('tolid_tolid_count') && doc
-                            ['calc_individual_exhausted_tolid_calc_individual_exhausted_value_count']
-                            .size() > 0 && doc['tolid_tolid_count'].size() > 0 && doc
-                            ['calc_individual_exhausted_tolid_calc_individual_exhausted_value_count']
-                            .value - doc['tolid_tolid_count'].value == 0
+                            ((!doc.containsKey('calc_individual_exhausted_tolid_count')
+                            || doc['calc_individual_exhausted_tolid_count'].size() == 0)
+                            && (!doc.containsKey('tolid_tolid_count') ||
+                            doc['tolid_tolid_count'].size() == 0)) ||
+                            (doc.containsKey('calc_individual_exhausted_tolid_count') &&
+                            doc.containsKey('tolid_tolid_count') &&
+                            doc['calc_individual_exhausted_tolid_count'].size() > 0 &&
+                            doc['tolid_tolid_count'].size() > 0 &&
+                            doc['calc_individual_exhausted_tolid_count'].value
+                            - doc['tolid_tolid_count'].value == 0)
                         );
 
                         emit(
@@ -426,16 +490,36 @@ def elastic():
                     """
                 }
             },
+            'calc_no_null_tolid_tolid_count': {
+                'type': 'double',
+                'script': {
+                    'source': """
+
+                        boolean isThereAValueNonNull = (
+                            doc.containsKey('tolid_tolid_count') &&
+                            doc['tolid_tolid_count'].size() > 0 &&
+                            doc['tolid_tolid_count']
+                            .value != null
+                        );
+
+                        if (isThereAValueNonNull) {
+                            emit(doc['tolid_tolid_count'].value);
+                        } else {
+                            emit(0.0);
+                        }
+                    """
+                }
+            }
         },
         'specimen': {
             'calc_coverage_post_run': RuntimeFields.math(
-                'mlwh_run_data_mlwh_hifi_read_bases_sum',
+                'tolqc_run_data_tolqc_bases_sum',
                 'sts_estimated_genome_size',
                 operation='/'
             )
         },
         'tolid': {
-            'calc_coverage': RuntimeFields.math('mlwh_run_data_mlwh_hifi_read_bases_sum',
+            'calc_coverage': RuntimeFields.math('tolqc_run_data_tolqc_bases_sum',
                                                 'tolid_species.sts_genome_size',
                                                 operation='/'),
             'calc_ongoing_submissions': RuntimeFields.math(
@@ -446,13 +530,13 @@ def elastic():
                 'type': 'boolean',
                 'script': {
                     'source': """
-                        if (doc.containsKey('mlwh_run_data_mlwh_hifi_read_bases_sum') &&
+                        if (doc.containsKey('tolqc_run_data_tolqc_bases_sum') &&
                         doc.containsKey('tolid_species.sts_genome_size') &&
                         doc.containsKey('sts_sample_sts_target_coverage_max') &&
-                        doc['mlwh_run_data_mlwh_hifi_read_bases_sum'].size() > 0 &&
+                        doc['tolqc_run_data_tolqc_bases_sum'].size() > 0 &&
                         doc['tolid_species.sts_genome_size'].size() > 0 &&
                         doc['sts_sample_sts_target_coverage_max'].size() > 0) {
-                            emit(doc['mlwh_run_data_mlwh_hifi_read_bases_sum'].value /
+                            emit(doc['tolqc_run_data_tolqc_bases_sum'].value /
                                 doc['tolid_species.sts_genome_size'].value >=
                                 doc['sts_sample_sts_target_coverage_max'].value)
                         }
@@ -466,49 +550,69 @@ def elastic():
                 'type': 'boolean',
                 'script': {
                     'source': """
-                        boolean isTotalSubmissionsGreaterThanZero = (
+                        boolean allRequiredFieldsPresent = (
                             doc.containsKey('benchling_pacbio_sequencing_request_count') &&
                             doc['benchling_pacbio_sequencing_request_count'].size() > 0 &&
-                            doc['benchling_pacbio_sequencing_request_count'].value > 0
+                            doc.containsKey(
+                                'benchling_pacbio_completed_sequencing_request_count'
+                            ) &&
+                            doc[
+                                'benchling_pacbio_completed_sequencing_request_count'
+                            ].size() > 0 &&
+                            doc.containsKey('tolqc_run_data_tolqc_bases_sum') &&
+                            doc['tolqc_run_data_tolqc_bases_sum'].size() > 0 &&
+                            doc.containsKey('tolid_species.sts_genome_size') &&
+                            doc['tolid_species.sts_genome_size'].size() > 0 &&
+                            doc.containsKey('sts_sample_sts_target_coverage_max') &&
+                            doc['sts_sample_sts_target_coverage_max'].size() > 0
                         );
 
-                        boolean isOngoingSubmissionsEqualZero = (
-                            doc.containsKey('benchling_pacbio_sequencing_request_count') &&
+                        if (!allRequiredFieldsPresent) {
+                            emit(false);
+                            return;
+                        }
+
+                        boolean isTotalSubmissionsGreaterThanZero =
+                            doc['benchling_pacbio_sequencing_request_count'].value > 0;
+
+                        boolean isOngoingSubmissionsEqualZero =
+                            ((!doc.containsKey('benchling_pacbio_sequencing_request_count') ||
+                            doc['benchling_pacbio_sequencing_request_count'].size() == 0) &&
+                            (!doc.containsKey('benchling_pacbio_completed_sequencing_request_count')
+                            || doc['benchling_pacbio_completed_sequencing_request_count']
+                            .size() == 0)) ||
+                            (doc.containsKey('benchling_pacbio_sequencing_request_count') &&
                             doc.containsKey('benchling_pacbio_completed_sequencing_request_count')
                             && doc['benchling_pacbio_sequencing_request_count'].size() > 0 &&
                             doc['benchling_pacbio_completed_sequencing_request_count'].size() > 0
-                            && (doc['benchling_pacbio_sequencing_request_count'].value -
-                            doc['benchling_pacbio_completed_sequencing_request_count'].value == 0)
-                        );
+                            && doc['benchling_pacbio_sequencing_request_count'].value -
+                            doc['benchling_pacbio_completed_sequencing_request_count'].value == 0);
 
-                        boolean isTargetCoverageMet = (
-                            doc.containsKey('mlwh_run_data_mlwh_hifi_read_bases_sum') &&
-                            doc.containsKey('tolid_species.sts_genome_size') &&
-                            doc.containsKey('sts_sample_sts_target_coverage_max') &&
-                            doc['mlwh_run_data_mlwh_hifi_read_bases_sum'].size() > 0 &&
-                            doc['tolid_species.sts_genome_size'].size() > 0 &&
-                            doc['sts_sample_sts_target_coverage_max'].size() > 0 &&
-                            (doc['mlwh_run_data_mlwh_hifi_read_bases_sum'].value /
+                        boolean isTargetCoverageMet =
+                            (doc['tolqc_run_data_tolqc_bases_sum'].value /
                             doc['tolid_species.sts_genome_size'].value >=
-                            doc['sts_sample_sts_target_coverage_max'].value)
-                            );
+                            doc['sts_sample_sts_target_coverage_max'].value);
 
                         boolean isSpecimenNotAtSequencingStage = false;
 
-                            if (doc.containsKey('informatics_status_summary.keyword') &&
-                                doc['informatics_status_summary.keyword'].size() > 0) {
+                        String statusField =
+                        'tolid_species.informatics_tolid_informatics_status_summary_min.keyword';
 
-                                for (String value : doc['informatics_status_summary.keyword']) {
-                                    if (value == '1 submitted' ||
-                                        value == '2 curated' ||
-                                        value == '3 curation' ||
-                                        value == '4 data complete' ||
-                                        value == '7 ignore') {
-                                        isSpecimenNotAtSequencingStage = true;
-                                        break;
-                                    }
+                        if (doc.containsKey(statusField) &&
+                            doc[statusField].size() > 0) {
+
+                            for (String value : doc[statusField]) {
+                                if (value == '1 submitted' ||
+                                    value == '2 curated' ||
+                                    value == '3 curation' ||
+                                    value == '4 data complete' ||
+                                    value == '7 ignore') {
+                                    isSpecimenNotAtSequencingStage = true;
+                                    break;
                                 }
                             }
+                        }
+
                         emit(
                             isTotalSubmissionsGreaterThanZero &&
                             isOngoingSubmissionsEqualZero &&
@@ -522,24 +626,25 @@ def elastic():
                 'type': 'boolean',
                 'script': {
                     'source': """
+                        boolean result = false;
+
                         boolean isTolidNotBeenActioned = (
                             !doc.containsKey('portaldb_date_topup_actioned') ||
                             doc['portaldb_date_topup_actioned'].size() == 0 ||
                             doc['portaldb_date_topup_actioned'].value == null
                         );
 
-                        boolean isTolidActionedBeforeLastRun = false;
-                        if (doc.containsKey('mlwh_run_data_mlwh_run_complete_max') &&
-                            doc.containsKey('portaldb_date_topup_actioned') &&
-                            doc['mlwh_run_data_mlwh_run_complete_max'].size() > 0 &&
-                            doc['portaldb_date_topup_actioned'].size() > 0) {
+                        if (isTolidNotBeenActioned) {
+                            result = true;
+                        }
+                        else if (doc.containsKey('mlwh_run_data_mlwh_run_complete_max') &&
+                                doc['mlwh_run_data_mlwh_run_complete_max'].size() > 0) {
 
-                            isTolidActionedBeforeLastRun =
-                                doc['portaldb_date_topup_actioned'].value.isBefore(
+                            result = doc['portaldb_date_topup_actioned'].value.isBefore(
                                 doc['mlwh_run_data_mlwh_run_complete_max'].value);
                         }
 
-                        emit(isTolidNotBeenActioned || isTolidActionedBeforeLastRun);
+                        emit(result);
                     """
                 }
             },
@@ -547,50 +652,59 @@ def elastic():
                 'type': 'boolean',
                 'script': {
                     'source': """
-                        boolean isIndividualExhausted = (
-                            doc.containsKey(
-                            'calc_sequencing_request_calc_mlwh_volume_remaining_max'
-                            ) && doc.containsKey(
-                            'calc_extraction_calc_benchling_volume_ul_dna_max'
-                            ) && doc.containsKey(
-                            'calc_tissue_prep_calc_benchling_weight_mg_max'
-                            ) && doc.containsKey(
-                            'calc_sample_calc_benchling_remaining_weight_max'
-                            ) && doc.containsKey(
-                            'benchling_sample_count'
-                            ) && doc.containsKey(
-                            'sts_sample_count'
-                            ) && doc[
-                            'calc_sequencing_request_calc_mlwh_volume_remaining_max'
-                            ].size() > 0 && doc[
-                            'calc_extraction_calc_benchling_volume_ul_dna_max'
-                            ].size() > 0 && doc[
-                            'calc_tissue_prep_calc_benchling_weight_mg_max'
-                            ].size() > 0 && doc[
-                            'calc_sample_calc_benchling_remaining_weight_max'
-                            ].size() > 0 && doc[
-                            'benchling_sample_count'
-                            ].size() > 0 && doc[
-                            'sts_sample_count'
-                            ].size() > 0 &&
-                            doc[
-                            'calc_sequencing_request_calc_mlwh_volume_remaining_max'
-                            ].value <= 0 &&
-                            doc['calc_extraction_calc_benchling_volume_ul_dna_max'
-                            ].value <= 0 && doc[
-                            'calc_tissue_prep_calc_benchling_weight_mg_max'
-                            ].value <= 0 && doc[
-                            'calc_sample_calc_benchling_remaining_weight_max'
-                            ].value <= 0 && doc[
-                            'benchling_sample_count'
-                            ].value == doc[
-                            'sts_sample_count'
-                            ].value
-                            );
+                        def benchlingNewSampleCount = 0;
+                        if (doc.containsKey('benchling_sample_count')
+                            && doc['benchling_sample_count'].size() > 0) {
+                            benchlingNewSampleCount = doc['benchling_sample_count'].value;
+                        }
 
-                        emit(
-                            isIndividualExhausted
-                        );
+                        def abandonCount = 0;
+                        if (doc.containsKey('calc_sample_abandoned_in_sts_sample_count')
+                            && doc['calc_sample_abandoned_in_sts_sample_count'].size() > 0) {
+                            abandonCount = doc['calc_sample_abandoned_in_sts_sample_count'].value;
+                        }
+
+                        def totalSampleCount = benchlingNewSampleCount + abandonCount;
+
+                        boolean allSamplesAccountedFor = false;
+                        if (doc.containsKey('sts_sample_count') &&
+                            doc['sts_sample_count'].size() > 0 &&
+                            totalSampleCount == doc['sts_sample_count'].value) {
+                            allSamplesAccountedFor = true;
+                        }
+
+                        boolean allBenchlingMaterialExhausted = false;
+                        if (benchlingNewSampleCount > 0 &&
+                            doc.containsKey(
+                            'calc_sequencing_request_calc_mlwh_volume_remaining_max')
+                            && doc.containsKey('
+                            calc_extraction_calc_benchling_volume_ul_dna_max')
+                            && doc.containsKey('
+                            calc_tissue_prep_calc_benchling_weight_mg_max')
+                            && doc.containsKey(
+                            'calc_sample_calc_benchling_remaining_weight_max')
+                            && doc['
+                            calc_sequencing_request_calc_mlwh_volume_remaining_max'].size() > 0
+                            && doc['
+                            calc_extraction_calc_benchling_volume_ul_dna_max'].size() > 0
+                            && doc['
+                            calc_tissue_prep_calc_benchling_weight_mg_max'].size() > 0
+                            && doc['
+                            calc_sample_calc_benchling_remaining_weight_max'].size() > 0
+                            && doc['
+                            calc_sequencing_request_calc_mlwh_volume_remaining_max'].value <= 0
+                            && doc['
+                            calc_extraction_calc_benchling_volume_ul_dna_max'].value <= 0
+                            && doc['
+                            calc_tissue_prep_calc_benchling_weight_mg_max'].value <= 0
+                            && doc['
+                            calc_sample_calc_benchling_remaining_weight_max'].value <= 0)
+                            {
+                            allBenchlingMaterialExhausted = true;
+                        }
+
+                        emit(allSamplesAccountedFor &&
+                            (benchlingNewSampleCount == 0 || allBenchlingMaterialExhausted));
                     """
                 }
             },
@@ -615,29 +729,49 @@ def elastic():
                         );
 
                         boolean isSpeciesTopUpEqualsIndividualExhausted = (
-                            doc.containsKey
-                            ('tolid_species.calc_topup_required_tolid_calc_topup_required_value_count')
-                            && doc.containsKey
-                            ('tolid_species.calc_individual_exhausted_tolid_calc_individual_exhausted_value_count')
-                            && doc
-                            ['tolid_species.calc_topup_required_tolid_calc_topup_required_value_count']
-                            .size() > 0 && doc
-                            ['tolid_species.calc_individual_exhausted_tolid_calc_individual_exhausted_value_count']
-                            .size() > 0 && (doc
-                            ['tolid_species.calc_topup_required_tolid_calc_topup_required_value_count']
-                            .value - doc
-                            ['tolid_species.calc_individual_exhausted_tolid_calc_individual_exhausted_value_count']
+                            ((!doc.containsKey('tolid_species.calc_topup_required_tolid_count') ||
+                            doc['tolid_species.calc_topup_required_tolid_count'].size() == 0) &&
+                            (!doc.containsKey(
+                            'tolid_species.calc_individual_exhausted_tolid_count') ||
+                            doc['tolid_species.calc_individual_exhausted_tolid_count']
+                            .size() == 0)) ||
+                            (doc.containsKey('tolid_species.calc_topup_required_tolid_count') &&
+                            doc.containsKey('tolid_species.calc_individual_exhausted_tolid_count')
+                            && doc['tolid_species.calc_topup_required_tolid_count']
+                            .size() > 0 &&
+                            doc['tolid_species.calc_individual_exhausted_tolid_count']
+                            .size() > 0 &&
+                            doc['tolid_species.calc_topup_required_tolid_count'].value -
+                            doc['tolid_species.calc_individual_exhausted_tolid_count']
                             .value == 0)
                         );
 
+                        boolean isSpecimenNotAtSequencingStage = false;
+
+                        if (doc.containsKey('informatics_status_summary.keyword') &&
+                            doc['informatics_status_summary.keyword'].size() > 0) {
+
+                            for (String value : doc['informatics_status_summary.keyword']) {
+                                if (value == '1 submitted' ||
+                                    value == '2 curated' ||
+                                    value == '3 curation' ||
+                                    value == '4 data complete' ||
+                                    value == '7 ignore') {
+                                    isSpecimenNotAtSequencingStage = true;
+                                    break;
+                                }
+                            }
+                        }
+
                         emit(
                             isThereAtLeastAnotherIndividual &&
                             isAtLeastOneIndividualExhausted &&
-                            isSpeciesTopUpEqualsIndividualExhausted
+                            isSpeciesTopUpEqualsIndividualExhausted &&
+                            !isSpecimenNotAtSequencingStage
                         );
                     """
                 }
-            },
+            }
         },
         'sample': {
             'calc_biospecimen_id': RuntimeFields.coalesce([
@@ -716,7 +850,7 @@ def elastic():
                 'type': 'double',
                 'script': {
                     'source': """
-                                            if (doc.containsKey('portaldb_date_abandoned') &&
+                        if (doc.containsKey('portaldb_date_abandoned') &&
                             doc['portaldb_date_abandoned'].size() > 0) {
                             emit(0.0);
                         } else if (doc.containsKey('benchling_remaining_weight') &&
@@ -733,6 +867,24 @@ def elastic():
                     """
                 }
             },
+            'calc_sample_eligible_for_sts_table': {
+                'type': 'boolean',
+                'script': {
+                    'source': """
+                        boolean isSampleAbandoned = doc.containsKey('portaldb_date_abandoned') &&
+                            doc['portaldb_date_abandoned'].size() > 0;
+
+                        boolean isSampleInBenchling = doc.containsKey('sts_eln_id.keyword') &&
+                            doc['sts_eln_id.keyword'].size() > 0;
+
+                        boolean isInSTSNotInBenchling = !isSampleAbandoned && !isSampleInBenchling;
+
+                        boolean isAbandonedInBenchling = isSampleAbandoned && isSampleInBenchling;
+
+                        emit(isInSTSNotInBenchling || isAbandonedInBenchling);
+                    """
+                }
+            },
             'calc_sample_abandoned_in_sts': {
                 'type': 'boolean',
                 'script': {
@@ -753,14 +905,28 @@ def elastic():
             },
         },
         'sampleset': {
-            'calc_tat': RuntimeFields.date_interval('sts_submit_date',
-                                                    'sts_sample_sts_receive_date_min',
-                                                    'days')
+            'calc_tat_days': RuntimeFields.date_interval(
+                'sts_submit_date',
+                'sts_sample_sts_receive_date_min',
+                'days'
+            ),
+            'calc_tat_weeks': RuntimeFields.date_interval(
+                'sts_submit_date',
+                'sts_sample_sts_receive_date_min',
+                'weeks'
+            )
         },
         'manifest': {
-            'calc_tat': RuntimeFields.date_interval('sts_submit_date',
-                                                    'sts_receive_date',
-                                                    'days')
+            'calc_tat_days': RuntimeFields.date_interval(
+                'sts_submit_date',
+                'sts_receive_date',
+                'days'
+            ),
+            'calc_tat_weeks': RuntimeFields.date_interval(
+                'sts_submit_date',
+                'sts_receive_date',
+                'weeks'
+            )
         },
         'sequencing_request': {
             'calc_existing_library_oplc': {
@@ -859,11 +1025,17 @@ def elastic():
         portal_attributes()
     )
 
+    # Set up the correct environment. Can be passed in as a parameter
+    # or be ELASTIC_ENVIRONMENT environment variable
+    # or not be set
+    if environment is None:
+        environment = os.getenv('ELASTIC_ENVIRONMENT')
+    index_suffix = f'-{environment}' if environment else ''
     elastic = ElasticDataSource({
         'uri': os.getenv('ELASTIC_URI'),
         'user': os.getenv('ELASTIC_USER'),
         'password': os.getenv('ELASTIC_PASSWORD'),
-        'index_prefix': os.getenv('ELASTIC_INDEX_PREFIX'),
+        'index_prefix': os.getenv('ELASTIC_INDEX_PREFIX') + index_suffix,
         'relationship_cfg': relationship_config,
         'runtime_fields': runtime_fields},
         attribute_metadata=amd)
