@@ -6,6 +6,7 @@ import os
 
 from .defaults import Defaults
 from ..api_client import (
+    ApiDataSource,
     create_api_datasource
 )
 from ..core import (
@@ -13,7 +14,7 @@ from ..core import (
 )
 
 
-def sts(retries: int = 5):
+def sts(retries: int = 5, **kwargs) -> ApiDataSource:
     sts = create_api_datasource(
         api_url=os.getenv('STS_URL', Defaults.STS_URL)
         + os.getenv('STS_API_PATH', Defaults.STS_API_PATH),
